@@ -10,7 +10,7 @@ class Map(Module):
         **kwargs,
     ):
         super().__init__(
-            module_id=module_id or function,
+            module_id=module_id or function.split(".")[-1],
             **kwargs,
         )
 
